@@ -87,10 +87,10 @@ def assert_helper(condition, msg):
 
 def re_match_helper(pattern, string):
     """Helper function for matching strings against regular expressions
-    in a Jinja2 template.  The regular expression is compiled and
-    matched against the supplied string (the Python regular expression
-    library caches compiled strings for efficiency) and a boolean is
-    returned, indicating whether the match succeeded or not.
+    in a Jinja2 template: a boolean is returned, indicating whether the
+    match succeeded or not.
+
+    This is a wrapper around re.match().
 
     Keyword arguments:
 
@@ -102,13 +102,50 @@ def re_match_helper(pattern, string):
     return bool(re.match(pattern, string))
 
 
+def re_match_group_helper(pattern, string, *groups):
+    """Helper function for matching strings against regular expressions
+    and extract selected groups (marked by parentheses) of text in a
+    Jinja2 template, returning them in the form of a tuple, one for
+    each group, in order.
+
+    The desired groups are identified either by number (0 for the first
+    one, by opening bracket, 1 for the second, etc.) or by name (using
+    the syntax '(?P<name>...)'.  These styles can be mixed.
+
+    This is a wrapper around re.match().group() (re.match() returns a
+    Match object and group() is called on that).
+
+    Keyword arguments:
+
+    pattern -- the regular expression to match against; the required
+    groups to return should be specified using parentheses
+
+    string -- the string to match and return the groups of
+
+    *groups -- a list of arguments giving the numbers or names of the
+    desired match groups
+    """
+
+    r = re.match(pattern, string)
+
+    if r is None:
+        raise ValueError("re_match_group() string: '%s' does not "
+                         "match pattern: '%s'" % (string, pattern))
+
+    return r.group(*groups)
+
+
 def re_match_groups_helper(pattern, string):
     """Helper function for matching strings against regular expressions
-    and extract groups of (separated by parentheses) in a Jinja2
-    template.  The regular expression is compiled and matched against
-    the supplied string (the Python regular expression library caches
-    compiled strings for efficiency) and the groups in the expression
-    are returned in the form of a list.
+    and extract groups (marked by parentheses) of text in a Jinja2
+    template, returning them in the form of a tuple, one for each pair.
+
+    The caller can extract the desired one by indexing the tuple.  To
+    select an arbitrary list of groups (by name),
+    re_match_group_helper() is more useful.
+
+    This is a wrapper around re.match().groups() (re.match() returns a
+    Match object and groups() is called on that).
 
     Keyword arguments:
 
@@ -121,8 +158,8 @@ def re_match_groups_helper(pattern, string):
     r = re.match(pattern, string)
 
     if r is None:
-        raise ValueError("'%s' does not match regular expression '%s'" %
-                             (string, pattern))
+        raise ValueError("re_match_groups() string: '%s' does not "
+                         "match pattern: '%s'" % (string, pattern))
 
     return r.groups()
 
@@ -435,6 +472,7 @@ env.globals["warn"] = warn_helper
 env.globals["raise"] = raise_helper
 env.globals["assert"] = assert_helper
 env.globals["re_match"] = re_match_helper
+env.globals["re_match_group"] = re_match_group_helper
 env.globals["re_match_groups"] = re_match_groups_helper
 
 env.globals["deepcopy"] = deepcopy
